## Info

- program: licensecheck
- version: 2025.1.0
- license: MIT LICENSE

## Project License

MIT LICENSE

## Packages

Find a list of packages below

|Compatible|Package|
|:--|:--|
|✔|aiohappyeyeballs|
|✔|aiohttp|
|✔|aiosignal|
|✔|annotated-types|
|✔|anyio|
|✔|attrs|
|✔|certifi|
|✔|charset-normalizer|
|✔|click|
|✔|colorama|
|✔|distro|
|✔|filelock|
|✔|frozenlist|
|✔|fsspec|
|✔|griffe|
|✔|h11|
|✔|hf-xet|
|✔|httpcore|
|✔|httpx|
|✔|huggingface-hub|
|✔|idna|
|✔|importlib-metadata|
|✔|iniconfig|
|✔|jinja2|
|✔|jiter|
|✔|jsonschema|
|✔|jsonschema-specifications|
|✔|litellm|
|✔|logfire-api|
|✔|markupsafe|
|✔|multidict|
|✔|openai|
|✔|packaging|
|✔|pluggy|
|✔|propcache|
|✔|pydantic|
|✔|pydantic-core|
|✔|pygments|
|✔|pytest|
|✔|pytest-asyncio|
|✔|python-dotenv|
|✔|pyyaml|
|✔|referencing|
|✔|regex|
|✔|requests|
|✔|rpds-py|
|✔|sniffio|
|✔|tenacity|
|✔|tiktoken|
|✔|tokenizers|
|✔|tqdm|
|✔|typing-extensions|
|✔|typing-inspection|
|✔|urllib3|
|✔|yarl|
|✔|zipp|

### aiohappyeyeballs-2.6.1

- HomePage: UNKNOWN
- Author: J. Nick Koston
- License: PYTHON SOFTWARE FOUNDATION LICENSE
- Compatible: True
- Size: -1

### aiohttp-3.12.15

- HomePage: https://github.com/aio-libs/aiohttp
- Author: UNKNOWN
- License: APACHE-2.0;; MIT
- Compatible: True
- Size: -1

### aiosignal-1.4.0

- HomePage: https://github.com/aio-libs/aiosignal
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: -1

### annotated-types-0.7.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: -1

### anyio-4.10.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

### attrs-23.2.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: 202960

### certifi-2025.8.3

- HomePage: https://github.com/certifi/python-certifi
- Author: Kenneth Reitz
- License: MOZILLA PUBLIC LICENSE 2.0 _MPL 2.0_
- Compatible: True
- Size: 294877

### charset-normalizer-3.4.3

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 826776

### click-8.2.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: -1

### colorama-0.4.6

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: -1

### distro-1.9.0

- HomePage: https://github.com/python-distro/distro
- Author: Nir Cohen
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: -1

### filelock-3.19.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: UNLICENSE
- Compatible: True
- Size: -1

### frozenlist-1.7.0

- HomePage: https://github.com/aio-libs/frozenlist
- Author: UNKNOWN
- License: APACHE-2.0
- Compatible: True
- Size: -1

### fsspec-2025.9.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: -1

### griffe-1.7.3

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: ISC
- Compatible: True
- Size: -1

### h11-0.16.0

- HomePage: https://github.com/python-hyper/h11
- Author: Nathaniel J. Smith
- License: MIT LICENSE
- Compatible: True
- Size: -1

### hf-xet-1.1.9

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: -1

### httpcore-1.0.9

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD-3-CLAUSE
- Compatible: True
- Size: -1

### httpx-0.28.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: -1

### huggingface-hub-0.34.4

- HomePage: https://github.com/huggingface/huggingface_hub
- Author: Hugging Face, Inc.
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: -1

### idna-3.10

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 349141

### importlib-metadata-8.7.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: -1

### iniconfig-2.1.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

### jinja2-3.1.6

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: -1

### jiter-0.10.0

- HomePage: https://github.com/pydantic/jiter/
- Author: Samuel Colvin <samuel@pydantic.dev>
- License: MIT LICENSE
- Compatible: True
- Size: -1

### jsonschema-4.25.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

### jsonschema-specifications-2025.4.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

### litellm-1.72.4

- HomePage: UNKNOWN
- Author: BerriAI
- License: MIT LICENSE
- Compatible: True
- Size: -1

### logfire-api-3.22.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

### markupsafe-3.0.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: -1

### multidict-6.6.4

- HomePage: https://github.com/aio-libs/multidict
- Author: Andrew Svetlov
- License: APACHE LICENSE 2.0
- Compatible: True
- Size: -1

### openai-1.104.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: -1

### packaging-25.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE;; BSD LICENSE
- Compatible: True
- Size: 236486

### pluggy-1.6.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: -1

### propcache-0.3.2

- HomePage: https://github.com/aio-libs/propcache
- Author: Andrew Svetlov
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: -1

### pydantic-2.11.5

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

### pydantic-core-2.33.2

- HomePage: https://github.com/pydantic/pydantic-core
- Author: UNKNOWN
- License: MIT LICENSE
- Compatible: True
- Size: -1

### pygments-2.19.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: BSD LICENSE
- Compatible: True
- Size: 4467170

### pytest-8.4.1

- HomePage: UNKNOWN
- Author: Holger Krekel, Bruno Oliveira, Ronny Pfannschmidt, Floris Bruynooghe, Brianna Laugher, Florian Bruhin, Others (See AUTHORS)
- License: MIT LICENSE
- Compatible: True
- Size: -1

### pytest-asyncio-1.0.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE-2.0
- Compatible: True
- Size: -1

### python-dotenv-1.1.1

- HomePage: https://github.com/theskumar/python-dotenv
- Author: Saurabh Kumar
- License: BSD LICENSE
- Compatible: True
- Size: -1

### pyyaml-6.0.2

- HomePage: https://pyyaml.org/
- Author: Kirill Simonov
- License: MIT LICENSE
- Compatible: True
- Size: -1

### referencing-0.36.2

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

### regex-2025.9.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE-2.0;; CNRI-PYTHON
- Compatible: True
- Size: -1

### requests-2.32.5

- HomePage: https://requests.readthedocs.io
- Author: Kenneth Reitz
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: 202504

### rpds-py-0.27.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

### sniffio-1.3.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE;; MIT LICENSE
- Compatible: True
- Size: -1

### tenacity-9.1.2

- HomePage: https://github.com/jd/tenacity
- Author: Julien Danjou
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: -1

### tiktoken-0.11.0

- HomePage: UNKNOWN
- Author: Shantanu Jain
- License: MIT LICENSE
- Compatible: True
- Size: -1

### tokenizers-0.22.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: -1

### tqdm-4.67.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT LICENSE;; MOZILLA PUBLIC LICENSE 2.0 _MPL 2.0_
- Compatible: True
- Size: -1

### typing-extensions-4.14.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: PSF-2.0
- Compatible: True
- Size: -1

### typing-inspection-0.4.1

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

### urllib3-2.5.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: 421374

### yarl-1.20.1

- HomePage: https://github.com/aio-libs/yarl
- Author: Andrew Svetlov
- License: APACHE SOFTWARE LICENSE
- Compatible: True
- Size: -1

### zipp-3.23.0

- HomePage: UNKNOWN
- Author: UNKNOWN
- License: MIT
- Compatible: True
- Size: -1

